@@ -34,10 +34,11 @@ OC.L10N.register(
     "Filename" : "ფაილის სახელი",
     "Cancel" : "უარყოფა",
     "Automatic" : "ავტომატური",
-    "or" : "ან",
     "List view" : "ჩამონათვლისებური ხედი",
     "Actions" : "მოქმედებები",
+    "or" : "ან",
     "Show week numbers" : "კვირის ნომრების ჩვენება",
+    "Update" : "განახლება",
     "Location" : "ადგილმდებარეობა",
     "Description" : "აღწერილობა",
     "to" : "ვის",
@@ -49,14 +50,15 @@ OC.L10N.register(
     "Friday" : "პარასკევი",
     "Saturday" : "შაბათი",
     "Sunday" : "კვირა",
-    "Update" : "განახლება",
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "Notification" : "შეტყობინება",
     "Email" : "ელ-ფოსტა",
-    "Delete file" : "გაუქმდეს ფაილი",
+    "days" : "დღე",
+    "weeks" : "კვირა",
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
-    "Done" : "დასრულდა",
+    "Delete file" : "გაუქმდეს ფაილი",
     "Unknown" : "ამოუცნობი",
+    "Done" : "დასრულდა",
     "Room name" : "ოთახის სახელი",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
